==> julia-git-differentiationinterface-src-0.5.15-2-any.pkg.tar.zst: usr/share/julia/arch-site/DifferentiationInterface/src/DifferentiationInterface.jl <==
"""
    DifferentiationInterface

An interface to various automatic differentiation backends in Julia.

# Exports

$(EXPORTS)
"""
module DifferentiationInterface

using ADTypes: ADTypes, AbstractADType
using ADTypes: mode, ForwardMode, ForwardOrReverseMode, ReverseMode, SymbolicMode
using ADTypes: AutoSparse, dense_ad
using ADTypes: coloring_algorithm
using ADTypes: sparsity_detector, jacobian_sparsity, hessian_sparsity
using ADTypes:
    AutoChainRules,
    AutoDiffractor,
    AutoEnzyme,
    AutoFastDifferentiation,
    AutoFiniteDiff,
    AutoFiniteDifferences,
    AutoForwardDiff,
    AutoPolyesterForwardDiff,
    AutoReverseDiff,
    AutoSymbolics,
    AutoTapir,
    AutoTracker,
    AutoZygote
using Compat
using DocStringExtensions
using FillArrays: OneElement
using LinearAlgebra: Symmetric, Transpose, dot, parent, transpose
using PackageExtensionCompat: @require_extensions
using SparseArrays: SparseMatrixCSC, nonzeros, nzrange, rowvals, sparse
using SparseMatrixColorings:
    AbstractColoringResult,
    ColoringProblem,
    GreedyColoringAlgorithm,
    coloring,
    column_colors,
    row_colors,
    column_groups,
    row_groups,
    decompress,
    decompress!

abstract type Extras end

include("second_order/second_order.jl")

include("utils/extras.jl")
include("utils/traits.jl")
include("utils/basis.jl")
include("utils/batch.jl")
include("utils/check.jl")
include("utils/exceptions.jl")
include("utils/maybe.jl")
include("utils/printing.jl")

include("first_order/pushforward.jl")
include("first_order/pushforward_batched.jl")
include("first_order/pullback.jl")
include("first_order/pullback_batched.jl")
include("first_order/derivative.jl")
include("first_order/gradient.jl")
include("first_order/jacobian.jl")

include("second_order/second_derivative.jl")
include("second_order/hvp.jl")
include("second_order/hvp_batched.jl")
include("second_order/hessian.jl")

include("fallbacks/no_extras.jl")

include("sparse/fallbacks.jl")
include("sparse/jacobian.jl")
include("sparse/hessian.jl")

include("misc/differentiate_with.jl")
include("misc/sparsity_detector.jl")
include("misc/from_primitive.jl")

function __init__()
    @require_extensions
end

## Exported

export SecondOrder

export value_and_pushforward!, value_and_pushforward
export value_and_pullback!, value_and_pullback

export value_and_derivative!, value_and_derivative
export value_and_gradient!, value_and_gradient
export value_and_jacobian!, value_and_jacobian

export pushforward!, pushforward
export pullback!, pullback

export derivative!, derivative
export gradient!, gradient
export jacobian!, jacobian

export second_derivative!, second_derivative
export value_derivative_and_second_derivative, value_derivative_and_second_derivative!
export hvp!, hvp
export hessian!, hessian
export value_gradient_and_hessian, value_gradient_and_hessian!

export prepare_pushforward, prepare_pushforward_same_point
export prepare_pullback, prepare_pullback_same_point
export prepare_hvp, prepare_hvp_same_point
export prepare_derivative, prepare_gradient, prepare_jacobian
export prepare_second_derivative, prepare_hessian

export check_available, check_twoarg, check_hessian

export DifferentiateWith
export DenseSparsityDetector

## Re-exported from ADTypes

export AutoChainRules
export AutoDiffractor
export AutoEnzyme
export AutoFastDifferentiation
export AutoFiniteDiff
export AutoFiniteDifferences
export AutoForwardDiff
export AutoPolyesterForwardDiff
export AutoReverseDiff
export AutoSymbolics
export AutoTapir
export AutoTracker
export AutoZygote

export AutoSparse

## Re-exported from SparseMatrixColorings

export GreedyColoringAlgorithm

## Public but not exported

@compat public inner
@compat public outer

end # module

==> julia-git-differentiationinterface-src-0.6.24-1-any.pkg.tar.zst: usr/share/julia/arch-site/DifferentiationInterface/src/DifferentiationInterface.jl <==
"""
    DifferentiationInterface

An interface to various automatic differentiation backends in Julia.
"""
module DifferentiationInterface

using ADTypes:
    ADTypes,
    AbstractADType,
    AutoSparse,
    ForwardMode,
    ForwardOrReverseMode,
    ReverseMode,
    SymbolicMode,
    dense_ad,
    mode
using ADTypes:
    AutoChainRules,
    AutoDiffractor,
    AutoEnzyme,
    AutoFastDifferentiation,
    AutoFiniteDiff,
    AutoFiniteDifferences,
    AutoForwardDiff,
    AutoMooncake,
    AutoPolyesterForwardDiff,
    AutoReverseDiff,
    AutoSymbolics,
    AutoTracker,
    AutoZygote
using LinearAlgebra: dot

include("compat.jl")

include("first_order/mixed_mode.jl")
include("second_order/second_order.jl")

include("utils/prep.jl")
include("utils/traits.jl")
include("utils/basis.jl")
include("utils/batchsize.jl")
include("utils/check.jl")
include("utils/exceptions.jl")
include("utils/printing.jl")
include("utils/context.jl")
include("utils/linalg.jl")

include("first_order/pushforward.jl")
include("first_order/pullback.jl")
include("first_order/derivative.jl")
include("first_order/gradient.jl")
include("first_order/jacobian.jl")

include("second_order/second_derivative.jl")
include("second_order/hvp.jl")
include("second_order/hessian.jl")

include("fallbacks/no_prep.jl")
include("fallbacks/change_prep.jl")

include("misc/differentiate_with.jl")
include("misc/from_primitive.jl")
include("misc/sparsity_detector.jl")
include("misc/zero_backends.jl")

## Exported

export Context, Constant, Cache
export MixedMode, SecondOrder

export value_and_pushforward!, value_and_pushforward
export value_and_pullback!, value_and_pullback

export value_and_derivative!, value_and_derivative
export value_and_gradient!, value_and_gradient
export value_and_jacobian!, value_and_jacobian

export pushforward!, pushforward
export pullback!, pullback

export derivative!, derivative
export gradient!, gradient
export jacobian!, jacobian

export second_derivative!, second_derivative
export value_derivative_and_second_derivative, value_derivative_and_second_derivative!
export hvp!, hvp, gradient_and_hvp, gradient_and_hvp!
export hessian!, hessian
export value_gradient_and_hessian, value_gradient_and_hessian!

export prepare_pushforward, prepare_pushforward_same_point
export prepare_pullback, prepare_pullback_same_point
export prepare_hvp, prepare_hvp_same_point
export prepare_derivative, prepare_gradient, prepare_jacobian
export prepare_second_derivative, prepare_hessian

export DifferentiateWith
export DenseSparsityDetector

export check_available, check_inplace

## Re-exported from ADTypes

export AutoChainRules
export AutoDiffractor
export AutoEnzyme
export AutoFastDifferentiation
export AutoFiniteDiff
export AutoFiniteDifferences
export AutoForwardDiff
export AutoMooncake
export AutoPolyesterForwardDiff
export AutoReverseDiff
export AutoSymbolics
export AutoTracker
export AutoZygote

export AutoSparse

## Public but not exported

@public inner, outer

end # module
